// BWFabricView.h -- show the "fabric" bacground, and let the user draw
//                   stitches.

#import <Cocoa/Cocoa.h>
#import "BWStitchGroup.h" // for BWIntRect

// notifications when the user adds a new stitch location,
// or they finish selecting the printable area
extern NSString *BWFabricViewNewStitchNotification;
extern NSString *BWFabricViewPrintableAreaNotification;


// constant indicating that the mouse isn't over a cell.
// Used when dealing with mouse motion events to highlight the
// cell under the mouse
#define BWFabricView_NO_TRACK (-1)


@class BWStitchGroup;


@interface BWFabricView : NSView
{
    // this is the model object
    BWStitchGroup *group;

    // stuff used when drawing the stitch labels
    NSMutableDictionary *textAttributes;

    // mouse tracking stuff
    int trackX, trackY;

    // the color to show in a cell when we track mouse-motion events
    NSColor *cellHighlightColor;

    // printableArea stuff
    int printAreaX, printAreaY;
    int printAreaW, printAreaH;

    // are we tracking the printable area?
    BOOL trackingPrintArea;

    // have we gotten the upper-left corner?
    BOOL gotTopLeft;

}

// make a view for printing or for making a PDF
- (id) initForPrintingWithGroup: (BWStitchGroup *) group;

// tell the view what model to get its information from
- (void) setStitchGroup: (BWStitchGroup *) group;

// start the mode for the user selecting the printable area
- (void) startTrackingPrintableArea;
- (void) stopTrackingPrintableArea;

// what has the user selected for the printable area?
- (BWIntRect) getTrackingPrintArea;


// private forward references

// how large an area the printable area overlays
- (NSSize) printableSize;

// given an x,y in the grid, what is the rectangle for that cell?
- (NSRect) rectForLocation: (BWStitchLocation) location;

@end // BWFabricView


