// BWStitchNoteDocument -- this is the controller class for the StitchNotator

#import <Cocoa/Cocoa.h>

@class BWStitchGroup;
@class BWFabricView;

@interface BWStitchNoteDocument : NSDocument
{
    // this is our model object
    BWStitchGroup *group;

    // UI controls for interface builder
    IBOutlet BWFabricView *fabricView;
    IBOutlet NSDrawer *prefsDrawer;

    IBOutlet NSSlider *fabricWidthSlider;
    IBOutlet NSSlider *fabricSpacingSlider;
    IBOutlet NSSlider *stitchSizeSlider;

    IBOutlet NSColorWell *fabricColorWell;
    IBOutlet NSColorWell *backgroundColorWell;
    IBOutlet NSColorWell *stitchColorWell;
    IBOutlet NSColorWell *textColorWell;

    IBOutlet NSPopUpButton *fontMenuButton;
    IBOutlet NSPopUpButton *sizeMenuButton;

    IBOutlet NSButton *boldCheckbox;
    IBOutlet NSButton *italicCheckbox;

    IBOutlet NSPopUpButton *numberDisplayButton;

    IBOutlet NSButton *drawerDisclosureButton;

    // undo support

    // all of these are used to coalesce changes made in a continuous
    // control, like a slider or a color well.
    // See the BWDocument-Undo.[hm] category for their usage
    NSNotificationQueue *undoQueue;

    // old values to undo back to when user is done 
    // manipulating controls

    float originalFabricWidth;
    float originalFabricSpacing;
    float originalStitchSize;

    NSColor *originalFabricColor;
    NSColor *originalBackgroundColor;
    NSColor *originalStitchColor;
    NSColor *originalTextColor;
} 


// interface builder actions

- (IBAction) toggleDrawer: (id) sender;

- (IBAction) changeFabricWidth: (id) sender;
- (IBAction) changeFabricSpacing: (id) sender;
- (IBAction) changeStitchSize: (id) sender;

- (IBAction) changeFabricColor: (id) sender;
- (IBAction) changeBackgroundColor: (id) sender;
- (IBAction) changeStitchColor: (id) sender;
- (IBAction) changeTextColor: (id) sender;

- (IBAction) changeFont: (id) sender;

- (IBAction) changeNumberDisplay: (id) sender;

- (IBAction) shiftStitches: (id) sender;


// private.  Called from the UI category

- (void) updateUI;

@end // BWStitchNoteDocument

